config

package
v0.0.0-...-dc1bdca Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 31, 2026 License: Apache-2.0 Imports: 0 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Generate

type Generate struct {
	// File selection: if all are false, client files are generated.
	// Set one or more to true to generate only those files.
	Types      bool // generate types.gen.go
	Client     bool // generate client.gen.go
	ClientTest bool // generate client.gen_test.go
	Server     bool // generate server.gen.go
	JS         bool // generate api.js
}

func (Generate) GoFiles

func (g Generate) GoFiles() bool

func (Generate) ShouldGenerate

func (g Generate) ShouldGenerate(f string) bool

shouldGenerate reports whether filename f should be written given cfg.

Jump to