Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Generate ¶
type Generate struct {
// File selection: if all are false, client files are generated.
// Set one or more to true to generate only those files.
Types bool // generate types.gen.go
Client bool // generate client.gen.go
ClientTest bool // generate client.gen_test.go
Server bool // generate server.gen.go
JS bool // generate api.js
}
func (Generate) ShouldGenerate ¶
shouldGenerate reports whether filename f should be written given cfg.
Click to show internal directories.
Click to hide internal directories.